@@ -240,8 +240,8 @@ enum  {
 TrackerSparqlScanner* tracker_sparql_scanner_new (gchar* input, glong len);
 TrackerSparqlScanner* tracker_sparql_scanner_construct (GType object_type, gchar* input, glong len);
 void uuid_generate (guchar* uuid);
-TrackerTurtleReader* tracker_turtle_reader_new (const char* path);
-TrackerTurtleReader* tracker_turtle_reader_construct (GType object_type, const char* path);
+TrackerTurtleReader* tracker_turtle_reader_new (const char* path, GError** error);
+TrackerTurtleReader* tracker_turtle_reader_construct (GType object_type, const char* path, GError** error);
 static char* tracker_turtle_reader_generate_bnodeid (TrackerTurtleReader* self, const char* user_bnodeid);
 GQuark tracker_sparql_error_quark (void);
 TrackerSparqlTokenType tracker_sparql_scanner_read_token (TrackerSparqlScanner* self, TrackerSourceLocation* token_begin, TrackerSourceLocation* token_end, GError** error);
@@ -284,7 +284,7 @@ static GType tracker_turtle_reader_state_get_type (void) {
 }
 
 
-TrackerTurtleReader* tracker_turtle_reader_construct (GType object_type, const char* path) {
+TrackerTurtleReader* tracker_turtle_reader_construct (GType object_type, const char* path, GError** error) {
 	GError * _inner_error_;
 	TrackerTurtleReader * self;
 	GMappedFile* _tmp0_;
@@ -298,9 +298,14 @@ TrackerTurtleReader* tracker_turtle_reader_construct (GType object_type, const c
 	self = (TrackerTurtleReader*) g_object_new (object_type, NULL);
 	_tmp0_ = g_mapped_file_new (path, FALSE, &_inner_error_);
 	if (_inner_error_ != NULL) {
-		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, _inner_error_->message);
-		g_clear_error (&_inner_error_);
-		return NULL;
+		if (_inner_error_->domain == G_FILE_ERROR) {
+			g_propagate_error (error, _inner_error_);
+			return;
+		} else {
+			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, _inner_error_->message);
+			g_clear_error (&_inner_error_);
+			return NULL;
+		}
 	}
 	self->priv->mapped_file = (_tmp1_ = _tmp0_, _g_mapped_file_free0 (self->priv->mapped_file), _tmp1_);
 	self->priv->scanner = (_tmp2_ = tracker_sparql_scanner_new (g_mapped_file_get_contents (self->priv->mapped_file), g_mapped_file_get_length (self->priv->mapped_file)), _g_object_unref0 (self->priv->scanner), _tmp2_);
@@ -312,8 +317,8 @@ TrackerTurtleReader* tracker_turtle_reader_construct (GType object_type, const c
 }
 
 
-TrackerTurtleReader* tracker_turtle_reader_new (const char* path) {
-	return tracker_turtle_reader_construct (TRACKER_TYPE_TURTLE_READER, path);
+TrackerTurtleReader* tracker_turtle_reader_new (const char* path, GError** error) {
+	return tracker_turtle_reader_construct (TRACKER_TYPE_TURTLE_READER, path, error);
 }
 
 
@@ -1635,13 +1640,16 @@ void tracker_turtle_reader_load (const char* path, GError** error) {
 	{
 		TrackerTurtleReader* reader;
 		tracker_data_begin_transaction ();
-		reader = tracker_turtle_reader_new (path);
+		reader = tracker_turtle_reader_new (path, &_inner_error_);
+		if (_inner_error_ != NULL) {
+			goto __finally3;
+		}
 		while (TRUE) {
 			gboolean _tmp0_;
 			_tmp0_ = tracker_turtle_reader_next (reader, &_inner_error_);
 			if (_inner_error_ != NULL) {
 				_g_object_unref0 (reader);
-				goto __finally1;
+				goto __finally3;
 			}
 			if (!_tmp0_) {
 				break;
@@ -1650,24 +1658,24 @@ void tracker_turtle_reader_load (const char* path, GError** error) {
 				tracker_data_insert_statement_with_uri (reader->priv->_subject, reader->priv->_predicate, reader->priv->_object, &_inner_error_);
 				if (_inner_error_ != NULL) {
 					_g_object_unref0 (reader);
-					goto __finally1;
+					goto __finally3;
 				}
 			} else {
 				tracker_data_insert_statement_with_string (reader->priv->_subject, reader->priv->_predicate, reader->priv->_object, &_inner_error_);
 				if (_inner_error_ != NULL) {
 					_g_object_unref0 (reader);
-					goto __finally1;
+					goto __finally3;
 				}
 			}
 		}
 		_g_object_unref0 (reader);
 	}
-	__finally1:
+	__finally3:
 	{
 		tracker_data_commit_transaction ();
 	}
 	if (_inner_error_ != NULL) {
-		if ((_inner_error_->domain == TRACKER_SPARQL_ERROR) || (_inner_error_->domain == TRACKER_DATA_ERROR)) {
+		if (((_inner_error_->domain == G_FILE_ERROR) || (_inner_error_->domain == TRACKER_SPARQL_ERROR)) || (_inner_error_->domain == TRACKER_DATA_ERROR)) {
 			g_propagate_error (error, _inner_error_);
 			return;
 		} else {
